from typing import Any


class SticklightApiKeyNotFoundError(Exception):
    """
    Exception raised when the Sticklight API key is not found.
    """

    def __init__(self, message: str, *args: Any, **kwargs: Any):
        self.message = message
        super().__init__(self.message, *args, **kwargs)


__all__ = ["SticklightApiKeyNotFoundError"]



from .consts import STICKLIGHT_API_KEY_ENV_VAR_NAME
from .errors import SticklightApiKeyNotFoundError


def resolve_sticklight_api_key(sticklight_api_key: str | None = None) -> str:
    """
    Resolve the Sticklight API key with the following order of precedence:
    1. Value passed to the function
    2. STICKLIGHT_API_KEY environment variable
    3. Raise an error
    """
    if sticklight_api_key:
        return sticklight_api_key

    import os

    sticklight_api_key = os.getenv(STICKLIGHT_API_KEY_ENV_VAR_NAME)
    if not sticklight_api_key:
        error_message = (
            f"Sticklight API key not found. "
            f"Either set the {STICKLIGHT_API_KEY_ENV_VAR_NAME} environment variable or pass it to the capture function."
        )
        raise SticklightApiKeyNotFoundError(error_message)
    return sticklight_api_key


__all__ = ["resolve_sticklight_api_key", "SticklightApiKeyNotFoundError"]



import typing

import requests

from .auth import resolve_sticklight_api_key
from .consts import STICKLIGHT_API_BASE_URL

if typing.TYPE_CHECKING:
    import aiohttp


def capture(
    data: dict, *, sticklight_api_key: str | None = None
) -> requests.Response:
    """
    Publish an event to Sticklight API.

    Args:
        data (dict): A free-form dictionary of data to publish.
        sticklight_api_key (str, optional): The Sticklight API key to use. Defaults to None.
            Either pass it to the function or set the STICKLIGHT_API_KEY environment variable.

    Returns:
        requests.Response: The response from the Sticklight API.
    """
    sticklight_api_key = resolve_sticklight_api_key(sticklight_api_key)
    response = requests.post(
        f"{STICKLIGHT_API_BASE_URL}/events-collect/v1/events",
        json=[data],
        headers={"accept": "application/json", "x-api-key": sticklight_api_key},
        timeout=5,
    )
    response.raise_for_status()
    return response


async def acapture(
    data: dict, *, sticklight_api_key: str | None = None
) -> "aiohttp.ClientResponse":
    """
    Publish an event to Sticklight API asynchronously.

    Args:
        data (dict): A free-form dictionary of data to publish.
        sticklight_api_key (str, optional): The Sticklight API key to use. Defaults to None.
            Either pass it to the function or set the STICKLIGHT_API_KEY environment variable.

    Returns:
        aiohttp.ClientResponse: The response from the Sticklight API.
    """
    import aiohttp

    sticklight_api_key = resolve_sticklight_api_key(sticklight_api_key)
    async with (
        aiohttp.ClientSession() as session,
        session.post(
            f"{STICKLIGHT_API_BASE_URL}/events-collect/v1/events",
            json=[data],
            headers={
                "accept": "application/json",
                "x-api-key": sticklight_api_key,
            },
            timeout=5,
        ) as response,
    ):
        response.raise_for_status()
        return response


__all__ = ["acapture", "capture"]
